package cleii.cibo;

import java.util.ArrayList;

public class Ristorante {
	private String nome;
	private ArrayList<Tavolo> aT;
	private ArrayList<Personale> aP;
	
	public Ristorante (String nome) {
		this.nome=nome;
		aT=new ArrayList<> ();
		aP=new ArrayList<> ();
	}
	
	/*  aggiunge ad aP il cameriere/sommelier p
	 *  se non è già presente (sfruttando il metodo cercaPersonale)
	 *  ritorna true se l'inserimento avviene
	 */
	public boolean addPersonale (Personale p) {
		if (!cercaPersonale(p)) {
			aP.add(p);
			return true;
		}
		return false;
	}
	
	
	private boolean cercaPersonale (Personale p) {
		for (Personale i:aP) {
			if (p.equals(i)) 
				return true;
		}
		return false;
	}
	
	/*
	 * addTavolo crea e aggiunge un nuovo tavolo 
	 * con cameriere e sommelier prescelti 
	 * all'arrayList dei tavoli aT.
	 * Restituisce il tavolo creato.
	 */
	public Tavolo addTavolo (Cameriere c, Sommelier s) {
		Tavolo t = new Tavolo (c,s);
		aT.add(t);
		return t;
	}
	
	
	/*
	 * calcola il ricavo totale del ristorante
	 * (somma dei totali di tutti i tavoli)
	 */
	public double calcolaTotale() {
		double totale=0;
		for (Tavolo t:aT) {
			totale += t.calcolaTotale();
		}
		return totale;
	}
	
	/*
	 * calcola il ricavo totale del ristorante 
	 * nei tavoli serviti da p
	 */
	public double calcolaTotale(Personale p) {
		double totale=0;
		for (Tavolo t:aT) {
			if (p.equals(t.getCameriere())||p.equals(t.getSommelier()))
				totale += t.calcolaTotale();
		}
		return totale;
	}
	
	
	public Tavolo migliorTavolo() {
		double max=0;
		Tavolo ris=null;
		for (Tavolo t:aT) {
			double totT=t.calcolaTotale();
			if (totT>max) {
				max=totT;
				ris=t;
			}
		}
		return ris;
	}
	
	public Personale migliorPersonale() {
		double max=0;
		Personale ris=null;
		for (Personale p:aP) {
			double totP=calcolaTotale(p);
			if (totP>max) {
				max=totP;
				ris=p;
			}
		}
		return ris;
	}
	

}
